Skip to contents

Checks the master startup sheets for loggers marked as nonresponsive handled between certain dates and returns per-manufacturer nonresponsive sheets.

Usage

nonresponsive_from_master(
  all_metadata_combined,
  nonresponsive_list,
  start_date = NULL,
  end_date = Inf
)

Arguments

all_metadata_combined

Tibble containing combined startup information from master startup sheets, as generated by load_all_master_import(TRUE)

nonresponsive_list

A list containing tibbles of unresponsive loggers for different manufacturers. The name of the list element should match the producer name in master_startup (e.g., "Lotek", "MigrateTech"). This can be generated with the load_nonresponsive function

start_date

Date or character string specifying the start date for considering nonresponsive loggers. If NULL, defaults to January 1st of the current year.

end_date

Date or character string specifying the end date for considering nonresponsive loggers. If NULL, defaults to Inf (no end date).

Value

Updated list of nonresponsive logger sheets