Prepare session batch for database import
prepare_session_batch.RdThis function prepares a session batch for database import by processing each batch and extracting relevant metadata. It adds deployments and retrievals associated with the sessions in each batch. In cases where sessions have multiple deployments or retrievals, those sessions are removed from the batch and a warning is logged.