Push multiple database import collections to database
push_db_import_collections.RdFunction to push multiple DBImportCollection objects to the database. Each collection is processed in turn using the push_db_import_collection function.
push_db_import_collections.RdFunction to push multiple DBImportCollection objects to the database. Each collection is processed in turn using the push_db_import_collection function.