Skip to contents

Function to push startups from a master import sheet to the database. It checks the database for existing startups and only imports new startups to avoid duplicates.

Usage

push_startup(startup)

Arguments

startup

A tibble containing session information from a DBImportCollection object.