SessionBatch Class
SessionBatch.RdA convenience class for storing a set of logger sessions along with the type of database import they require.
See also
Other classes:
DBImportCollection,
LoadedWB,
LoadedWBCollection
Public fields
sessionsTibble containing session information from master import startup_shutdown.
typeThe type of import that needs to occur. Must be either "close_only", "open_only" or "open_and_close".
Methods
Method new()
Create a new SessionBatch object
Usage
SessionBatch$new(
sessions = tibble(),
type = c("close_only", "open_only", "open_and_close")
)Method print()
Print method for SessionBatch