Check existing deployments in database
check_deployment_db.RdFunction to check which deployments from the master import sheet are not already present in the database.
It constructs a dataframe of deployment dates and individ IDs, and uses the check_db_metadata_import function
to determine which deployments are new and need to be added to the database.