Check existing shutdowns in database
check_shutdown_db.RdFunction to check which shutdowns from the master import sheet are not already present in the database.
It constructs a dataframe of session IDs and download dates, and uses the check_db_metadata_import function
to determine which shutdowns are new and need to be added to the database.