Check existing startups in database
check_startups_db.RdFunction to check which startups from the master import sheet are not already present in the database.
It constructs a dataframe of session IDs and start times, and uses the check_db_metadata_import function
to determine which startups are new and need to be added to the database.