Given a new master import, modify all master imports in a list sharing the same path
modify_master_import_in_list.RdWhen loading all master import files with distinct = FALSE, we will end up with duplicate master import files. This is because multiple colonies can share the same master import file. If we modify one of these (for example, updating from partner metadata for that colony), we need to make sure the files stay in sync.