Extracts data from the SEATRACK DB and prepares it for the ColonyRepr functions
prep_SEATRACK_ColonyRepr.RdThis function will extract gls positional data for the specified species-colony. An active connection with the data base is required for this. It will then prepare the extracted data to be used in the ColonyRepr functions