Push master import file to database
push_master_import_file_to_db.RdFunction to push a master import file to the database. The function loads the master import file, prepares the data for database import, and then pushes the data to the database using the push_db_import_collections function.