Push startups to database
push_startup.RdFunction to push startups from a master import sheet to the database. It checks the database for existing startups and only imports new startups to avoid duplicates.
push_startup.RdFunction to push startups from a master import sheet to the database. It checks the database for existing startups and only imports new startups to avoid duplicates.